@@ -1,5 +1,9 @@
+options(error = recover)
 set.seed(15331)
 library(intamap)
+library(automap)
+library(gstat)
+library(psgp)
 #loadMeuse()
 
 crs = CRS("+init=epsg:28992 +proj=sterea +lat_0=52.15616055555555 +lon_0=5.38763888888889 +k=0.9999079 +x_0=155000 +y_0=463000 +ellps=bessel +towgs84=565.417,50.3319,465.552,-0.398957,0.343988,-1.8774,4.0725 +units=m +no_defs")
@@ -30,7 +34,7 @@ data(meuse)
 meuse = meuse[sample(dim(meuse)[1],30),]
 meuse$value=meuse$zinc
 coordinates(meuse) = ~x+y
-mgrid = spsample(meuse,25,"regular")
+mgrid = spsample(meuse,10,"regular")
 gridded(mgrid) = TRUE
 output = interpolate(meuse, mgrid, list(mean=T, variance=T, excprob = 1000,quantile = 0.5),
                      methodName = "copula")
@@ -39,19 +43,14 @@ output2 = interpolate(meuse, mgrid, list(mean=T, variance=T, excprob = 1000,quan
                      methodName = "copula",optList = list(methodParameters = output$methodParameters))
 
 output3 = interpolate(meuse, mgrid, list(mean=T, variance=T, excprob = 1000,quantile = 0.5),
-                     methodName = "copula",optList = list(methodParameters = output$methodParameters, nclus = 5))
-
+                     methodName = "automap",optList = list(model = c("Exp", "Sph")), cv = TRUE)
 output4 = interpolate(meuse, mgrid, list(mean=T, variance=T, excprob = 1000,quantile = 0.5),
-                     methodName = "automap",optList = list(methodParameters = output$methodParameters, nclus = 5))
+                     methodName = "psgp", cv = TRUE)
 
-output5 = interpolate(meuse, mgrid, list(mean=T, variance=T, excprob = 1000,quantile = 0.5),
-                     methodName = "automap",optList = list(model = "Sph", nclus = 5))
-
-summary(t(output2$outputTable))
+summary(t(output$outputTable))
 
 output2$outputTable - output$outputTable
-output3$outputTable - output$outputTable
-output4$outputTable - output$outputTable
-output5$outputTable - output$outputTable
 
+summary(output3$predictions)
+summary(output4$predictions)
 
